@@ -9,6 +9,7 @@
 
 #include <limits.h>
 #include <stdint.h>
+#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -72,7 +73,7 @@ typedef struct {
 struct _GVfsBackendAfc {
   GVfsBackend backend;
 
-  char *uuid;
+  char uuid[41];
   char *service;
   char *model;
   gboolean connected;
@@ -471,11 +472,16 @@ g_vfs_backend_afc_mount (GVfsBackend *backend,
     {
       g_vfs_job_failed (G_VFS_JOB (job),
                         G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                        _("Invalid mount spec"));
+      return;
+    }
+  if (G_UNLIKELY(sscanf(str, "%40s", (char *) &self->uuid) < 1))
+    {
+      g_vfs_job_failed (G_VFS_JOB(job), G_IO_ERROR, G_IO_ERROR_FAILED,
                         _("Invalid AFC location: must be in the form of "
                           "afc://uuid:port-number"));
       return;
     }
-  self->uuid = g_strdup (str);
 
   str = g_mount_spec_get (spec, "port");
   if (str == NULL)
@@ -513,7 +519,9 @@ g_vfs_backend_afc_mount (GVfsBackend *backend,
   display_name = NULL;
 
   real_spec = g_mount_spec_new ("afc");
-  g_mount_spec_set (real_spec, "host", self->uuid);
+  tmp = g_strdup_printf ("%40s", (char *) &self->uuid);
+  g_mount_spec_set (real_spec, "host", tmp);
+  g_free (tmp);
 
   /* INFO: Don't ever set the DefaultPort again or everything goes crazy */
   if (virtual_port != VIRTUAL_PORT_AFC)
@@ -1333,7 +1341,7 @@ g_vfs_backend_afc_replace (GVfsBackend *backend,
       g_vfs_job_failed (G_VFS_JOB (job),
                         G_IO_ERROR,
                         G_IO_ERROR_CANT_CREATE_BACKUP,
-                        _("Backups are not yet supported."));
+                        _("Backups not supported"));
       return;
     }
 
@@ -2418,7 +2426,7 @@ g_vfs_backend_afc_set_attribute (GVfsBackend *backend,
     {
       g_vfs_job_failed (G_VFS_JOB (job),
 			G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-			_("Operation unsupported"));
+			_("Operation not supported"));
       return;
     }
 
@@ -2744,8 +2752,6 @@ g_vfs_backend_afc_finalize (GObject *obj)
       self->force_umount_id = 0;
   }
 
-  g_free (self->uuid);
-
   if (G_OBJECT_CLASS(g_vfs_backend_afc_parent_class)->finalize)
     (*G_OBJECT_CLASS(g_vfs_backend_afc_parent_class)->finalize) (obj);
 }
