@@ -1118,7 +1118,7 @@ g_vfs_backend_google_copy (GVfsBackend           *_self,
        * G_IO_ERROR_CANT_CREATE_BACKUP to proceed with the GIO
        * fallback copy.
        */
-      g_vfs_job_failed_literal (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed_literal (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -1151,7 +1151,7 @@ g_vfs_backend_google_copy (GVfsBackend           *_self,
       g_vfs_job_failed_literal (G_VFS_JOB (job),
                                 G_IO_ERROR,
                                 G_IO_ERROR_FAILED,
-                                _("Operation unsupported"));
+                                _("Operation not supported"));
       goto out;
     }
 
@@ -1166,7 +1166,7 @@ g_vfs_backend_google_copy (GVfsBackend           *_self,
           g_vfs_job_failed_literal (G_VFS_JOB (job),
                                     G_IO_ERROR,
                                     G_IO_ERROR_NOT_SUPPORTED,
-                                    _("Operation unsupported"));
+                                    _("Operation not supported"));
           goto out;
         }
       else
@@ -1253,7 +1253,7 @@ g_vfs_backend_google_create_dir_monitor (GVfsBackend          *_self,
 
   if (flags & G_FILE_MONITOR_SEND_MOVED)
     {
-      g_vfs_job_failed_literal (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed_literal (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -1329,7 +1329,7 @@ g_vfs_backend_google_delete (GVfsBackend   *_self,
 
   if (entry == self->root)
     {
-      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -1483,7 +1483,7 @@ g_vfs_backend_google_make_directory (GVfsBackend          *_self,
 
   if (g_strcmp0 (filename, "/") == 0)
     {
-      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -1711,7 +1711,7 @@ g_vfs_backend_google_push (GVfsBackend           *_self,
        * G_IO_ERROR_CANT_CREATE_BACKUP to proceed with the GIO
        * fallback copy.
        */
-      g_vfs_job_failed_literal (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed_literal (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -2353,7 +2353,7 @@ g_vfs_backend_google_set_display_name (GVfsBackend           *_self,
 
   if (entry == self->root)
     {
-      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -2408,7 +2408,7 @@ g_vfs_backend_google_create (GVfsBackend         *_self,
 
   if (g_strcmp0 (filename, "/") == 0)
     {
-      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
@@ -2431,7 +2431,7 @@ g_vfs_backend_google_create (GVfsBackend         *_self,
           g_vfs_job_failed_literal (G_VFS_JOB (job),
                                     G_IO_ERROR,
                                     G_IO_ERROR_NOT_SUPPORTED,
-                                    _("Operation unsupported"));
+                                    _("Operation not supported"));
           goto out;
         }
       else
@@ -2517,7 +2517,7 @@ g_vfs_backend_google_replace (GVfsBackend         *_self,
 
   if (g_strcmp0 (filename, "/") == 0)
     {
-      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation unsupported"));
+      g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("Operation not supported"));
       goto out;
     }
 
